void processConnect(Task *task);

void processRspLogin(Task *task);

void processRtnContactInfo(Task *task);

void processRspRequestVertificateCode(Task *task);

void processRspRequestVerifyIdentity(Task *task);

void processRspSetVertificateCode(Task *task);

void processRtnErrorMsg(Task *task);

void processAPIReady(Task *task);

void processDisconnect(Task *task);

void processRspSubmitUserLoginInfo(Task *task);

void processRspChangePassword(Task *task);

void processRspSetReservedInfo(Task *task);

void processRtnContract(Task *task);

void processRtnFund(Task *task);

void processRtnOrder(Task *task);

void processRspOrderAction(Task *task);

void processRspQryOrderProcess(Task *task);

void processRtnFill(Task *task);

void processRtnPosition(Task *task);

void processRtnClose(Task *task);

void processRtnPositionProfit(Task *task);

void processRspQryDeepQuote(Task *task);

void processRtnExchangeStateInfo(Task *task);

void processRtnReqQuoteNotice(Task *task);

void processRspAccountRentInfo(Task *task);

void processRspTradeMessage(Task *task);

void processRtnTradeMessage(Task *task);

void processRspQryHisOrder(Task *task);

void processRspQryHisOrderProcess(Task *task);

void processRspQryHisFill(Task *task);

void processRspQryHisPosition(Task *task);

void processRspQryHisDelivery(Task *task);

void processRspQryAccountCashAdjust(Task *task);

void processRspQryBill(Task *task);

void processRspAccountFeeRent(Task *task);

void processRspAccountMarginRent(Task *task);

void processRspAddMobileDevice(Task *task);

void processRspQryManageInfoForEStar(Task *task);

void processRspQrySystemParameter(Task *task);

void processRspQryTradeCenterFrontAddress(Task *task);

void processRtnCommodityInfo(Task *task);

void processRtnCurrencyInfo(Task *task);

void processRspQryAccountStorage(Task *task);

void processRtnAccountStorage(Task *task);

void processRspQrySpotLock(Task *task);

void processRtnSpotLock(Task *task);

void processRspSpecialOrderAction(Task *task);

void processRtnSpecialOrder(Task *task);

void processRtnCombinePosition(Task *task);

void processRtnContractQuote(Task *task);

void processRspQryTrustDevice(Task *task);

void processRspAddTrustDevice(Task *task);

void processRspDelTrustDevice(Task *task);

void processRtnAddUserRight(Task *task);

void processRtnDelUserRight(Task *task);

void processRspQryManagerConfigFile(Task *task);

